==> batchcomputecli-0.0.10.tar.gz: batchcomputecli-0.0.10/batchcomputecli/actions/job.py <==
from ..services import client,printer,util,oss_client
from terminal import *


def getDetail(job_id, task_name=None, instance_id=None):

    if task_name==None:
        show_job_detail(job_id)

    elif instance_id==None:
        show_task_detail(job_id, task_name)

    else:
        show_instance_detail(job_id, task_name, instance_id)


def show_job_detail(job_id):

    job = client.get_job(job_id)

    job_list = [job]

    # format Date
    job_list = printer.format_date_fields(job_list,['StartTime','EndTime'], util.JOB_KEYS)

    # calc Progress
    job_list = util.calc_job_progress(job_list)

    print('\n%s: %s' % (bold(magenta('Job:')), job_id))

    printer.print_arr(job_list, util.JOB_COLS[1:]  + ['Priority'])


    print('\n%s' % bold(magenta('Tasks:')) )

    tasks = client.list_tasks(job_id)
    # format Date
    task_list = printer.format_date_fields(tasks,['StartTime', 'EndTime'], util.TASK_KEYS)
    # calc Progress
    task_list = util.calc_task_progress(task_list)

    printer.print_arr(task_list, util.TASK_COLS)

    print('\n')

def show_task_detail(job_id, task_name):

    #################
    des = client.get_job_description(job_id)
    task_desc = des.get('TaskDag').get('TaskDescMap').get(task_name)

    if not task_desc:
        raise Exception('Not found task: %s' % task_name)

    print('\n%s' % bold(magenta('Task Description:')))
    #print task_desc
    printer.print_task_desc(task_name, task_desc)

    #printer.print_arr([util.to_dict(task_desc,util.TASK_DESC_COLS)], util.TASK_DESC_COLS)

    ################
    tasks = client.list_tasks(job_id)
    task = [item for item in tasks if item.TaskName==task_name][0]

    print('\n%s' % bold(magenta('Task Status:')))
    # format Date
    task_list = printer.format_date_fields([task],['StartTime', 'EndTime'], util.TASK_KEYS)
    # calc Progress
    task_list = util.calc_task_progress(task_list)
    # print task
    printer.print_arr(task_list, util.TASK_COLS)

    stateCount = task_list[0].get('StateCount')
    stateStr = util.state_count_flat(stateCount)

    ################
    print('\n%s' % bold(magenta('Instances:')))
    print(stateStr)
    print('-'*90)

    inst_list = task['InstanceList']
    printer.print_instance_blocks(inst_list)
    print('\n')


def show_instance_detail(job_id, task_name, instance_id):
    des = client.get_job_description(job_id)
    task_desc = des.get('TaskDag').get('TaskDescMap').get(task_name)

    if not task_desc:
        raise Exception('Not found task: %s' % task_name)

    stdout_pre = '%s%s/stdout.%s' % (task_desc.get('StdoutRedirectPath'), task_name, instance_id)
    stderr_pre = '%s%s/stderr.%s' % (task_desc.get('StderrRedirectPath'), task_name, instance_id)

    arr1 = oss_client.list(stdout_pre)
    arr2 = oss_client.list(stderr_pre)

    for k in arr2:
        arr1.append(k)
    arr1.sort(__sort_logs_cpm)

    print('\n%s' % bold(magenta('Instance Log:')) )
    printer.print_arr(arr1, ['log_path','time'])


def __sort_logs_cpm(a,b):
    if a['time'] == b['time']: return 0
    elif a['time'] > b['time']: return -1
    else: return 1;

==> batchcomputecli-0.0.11.tar.gz: batchcomputecli-0.0.11/batchcomputecli/actions/job.py <==
from ..services import client,printer,util,oss_client
from terminal import *
from ..const import COMMAND


def getDetail(job_id, task_name=None, instance_id=None, limit=20):

    if task_name==None:
        show_job_detail(job_id)

    elif instance_id==None:
        show_task_detail(job_id, task_name)

    else:
        show_instance_detail(job_id, task_name, instance_id, limit)


def show_job_detail(job_id):

    job = client.get_job(job_id)

    job_list = [job]

    # format Date
    job_list = printer.format_date_fields(job_list,['StartTime','EndTime'], util.JOB_KEYS)

    # calc Progress
    job_list = util.calc_job_progress(job_list)

    print('\n%s: %s' % (bold(magenta('Job:')), job_id))

    printer.print_arr(job_list, util.JOB_COLS[1:]  + ['Priority'], False)


    print('\n%s' % bold(magenta('Tasks:')) )

    tasks = client.list_tasks(job_id)
    # format Date
    task_list = printer.format_date_fields(tasks,['StartTime', 'EndTime'], util.TASK_KEYS)
    # calc Progress
    task_list = util.calc_task_progress(task_list)

    printer.print_arr(task_list, util.TASK_COLS, False)

    print('\n')

def show_task_detail(job_id, task_name):

    #################
    des = client.get_job_description(job_id)
    task_desc = des.get('TaskDag').get('TaskDescMap').get(task_name)

    if not task_desc:
        raise Exception('Not found task: %s' % task_name)

    print('\n%s' % bold(magenta('Task Description:')) )
    #print task_desc
    printer.print_task_desc(task_name, task_desc)

    #printer.print_arr([util.to_dict(task_desc,util.TASK_DESC_COLS)], util.TASK_DESC_COLS)

    ################
    tasks = client.list_tasks(job_id)
    task = [item for item in tasks if item.TaskName==task_name][0]

    print('\n%s' % bold(magenta('Task Status:')))
    # format Date
    task_list = printer.format_date_fields([task],['StartTime', 'EndTime'], util.TASK_KEYS)
    # calc Progress
    task_list = util.calc_task_progress(task_list)
    # print task
    printer.print_arr(task_list, util.TASK_COLS, False)

    stateCount = task_list[0].get('StateCount')
    stateStr = util.state_count_flat(stateCount)

    ################
    print('\n%s (%s)' % (bold(magenta('Instances:')) , stateStr))
    print('%s' % gray('-'*90))

    inst_list = task['InstanceList']
    printer.print_instance_blocks(inst_list)
    printer.tip('Type "%s job %s %s <instance_id>" to get instance log list' % (COMMAND, job_id, task_name))


def show_instance_detail(job_id, task_name, instance_id, limit):
    des = client.get_job_description(job_id)
    task_desc = des.get('TaskDag').get('TaskDescMap').get(task_name)

    if not task_desc:
        raise Exception('Not found task: %s' % task_name)

    stdout_pre = '%s%s/stdout.%s' % (oss_dir_path(task_desc.get('StdoutRedirectPath')), task_name, instance_id)
    stderr_pre = '%s%s/stderr.%s' % (oss_dir_path(task_desc.get('StderrRedirectPath')), task_name, instance_id)

    arr1 = oss_client.list(stdout_pre)
    arr2 = oss_client.list(stderr_pre)

    for k in arr2:
        arr1.append(k)
    arr1.sort(__sort_logs_cpm)

    print('\n%s' % bold(magenta('Instance Log (last %d rows):' % limit)) )
    printer.print_arr(arr1[:limit], ['log_path','time','size'])
    printer.total(len(arr1))
    printer.tip('Type "%s log <log_path>" to get log content.' % COMMAND)

def oss_dir_path(s):
    if(s.endswith('/')):
        return s
    else:
        return '%s/' % s

def __sort_logs_cpm(a,b):
    if a['time'] == b['time']: return 0
    elif a['time'] > b['time']: return -1
    else: return 1;

def transform_limit(limit=20):
    try:
        return int(limit)
    except:
        raise Exception('--limit must be a Positive interger')
